@@ -1,4 +1,4 @@
-get_predictions_gam <- function(model, fitfram, ci.lvl, linv, type, ...) {
+get_predictions_gam <- function(model, data_grid, ci.lvl, linv, type, ...) {
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
   # compute ci, two-ways
@@ -7,21 +7,24 @@ get_predictions_gam <- function(model, fitfram, ci.lvl, linv, type, ...) {
   else
     ci <- 0.975
 
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+
   mi <- insight::model_info(model)
 
   if (!mi$is_zero_inflated && type %in% c("fe.zi", "re.zi")) {
     type <- "fe"
-    message(sprintf("Model has no zero-inflation part. Changing prediction-type to \"%s\".", type))
+    insight::format_alert(sprintf("Model has no zero-inflation part. Changing prediction-type to \"%s\".", type))
   }
 
 
-  prdat <-
-    stats::predict(
-      model,
-      newdata = fitfram,
-      type = "link",
-      se.fit = se
-    )
+  prdat <- stats::predict(
+    model,
+    newdata = data_grid,
+    type = "link",
+    se.fit = se
+  )
 
 
   if (type == "fe.zi") {
@@ -38,7 +41,7 @@ get_predictions_gam <- function(model, fitfram, ci.lvl, linv, type, ...) {
 
     # simulate predictions, for standad errors / CI
 
-    prdat.sim <- .get_zeroinfl_gam_predictions(model = model, newdata = fitfram, nsim = nsim)
+    prdat.sim <- .get_zeroinfl_gam_predictions(model = model, newdata = data_grid, nsim = nsim)
 
 
     # make sure we have only predicted values as vector, no SE
@@ -64,36 +67,36 @@ get_predictions_gam <- function(model, fitfram, ci.lvl, linv, type, ...) {
 
       insight::print_color("Error: Confidence intervals could not be computed.\n", "red")
 
-      fitfram$predicted <- prdat
-      fitfram$conf.low <- NA
-      fitfram$conf.high <- NA
+      data_grid$predicted <- prdat
+      data_grid$conf.low <- NA
+      data_grid$conf.high <- NA
 
     } else {
 
       sims <- exp(prdat.sim$cond) * (1 - stats::plogis(prdat.sim$zi))
 
-      fitfram$predicted <- prdat
-      fitfram$std.error <- apply(sims, 1, stats::sd)
+      data_grid$predicted <- prdat
+      data_grid$std.error <- apply(sims, 1, stats::sd)
 
       conf.low <- apply(sims, 1, stats::quantile, probs = 1 - ci)
       conf.high <- apply(sims, 1, stats::quantile, probs = ci)
       ci.range <- (conf.high - conf.low) / 2
 
       # fix negative CI
-      ci.low <- fitfram$predicted - ci.range
+      ci.low <- data_grid$predicted - ci.range
       neg.ci <- ci.low < 0
       if (any(neg.ci)) {
         ci.range[neg.ci] <- ci.range[neg.ci] - abs(ci.low[neg.ci]) - 1e-05
-        fitfram$std.error[neg.ci] <- fitfram$std.error[neg.ci] - ((abs(ci.low[neg.ci]) + 1e-05) / stats::qnorm(ci))
+        data_grid$std.error[neg.ci] <- data_grid$std.error[neg.ci] - ((abs(ci.low[neg.ci]) + 1e-05) / tcrit)
       }
 
-      fitfram$conf.low <- fitfram$predicted - ci.range
-      fitfram$conf.high <- fitfram$predicted + ci.range
+      data_grid$conf.low <- data_grid$predicted - ci.range
+      data_grid$conf.high <- data_grid$predicted + ci.range
 
-      if (.obj_has_name(fitfram, "std.error")) {
+      if (.obj_has_name(data_grid, "std.error")) {
         # copy standard errors
-        attr(fitfram, "std.error") <- fitfram$std.error
-        fitfram <- .remove_column(fitfram, "std.error")
+        attr(data_grid, "std.error") <- data_grid$std.error
+        data_grid <- .remove_column(data_grid, "std.error")
       }
     }
 
@@ -112,24 +115,24 @@ get_predictions_gam <- function(model, fitfram, ci.lvl, linv, type, ...) {
     # did user request standard errors? if yes, compute CI
     if (se) {
       # copy predictions
-      fitfram$predicted <- linv(prdat$fit)
+      data_grid$predicted <- linv(prdat$fit)
 
       # calculate CI
-      fitfram$conf.low <- linv(prdat$fit - stats::qnorm(ci) * prdat$se.fit)
-      fitfram$conf.high <- linv(prdat$fit + stats::qnorm(ci) * prdat$se.fit)
+      data_grid$conf.low <- linv(prdat$fit - tcrit * prdat$se.fit)
+      data_grid$conf.high <- linv(prdat$fit + tcrit * prdat$se.fit)
 
       # copy standard errors
-      attr(fitfram, "std.error") <- prdat$se.fit
+      attr(data_grid, "std.error") <- prdat$se.fit
 
     } else {
       # copy predictions
-      fitfram$predicted <- linv(as.vector(prdat))
+      data_grid$predicted <- linv(as.vector(prdat))
 
       # no CI
-      fitfram$conf.low <- NA
-      fitfram$conf.high <- NA
+      data_grid$conf.low <- NA
+      data_grid$conf.high <- NA
     }
 
-    fitfram
+    data_grid
   }
 }
