@@ -1,4 +1,4 @@
-get_predictions_mixor <- function(model, fitfram, ci.lvl, linv, value_adjustment, terms, model_class, condition, ...) {
+get_predictions_mixor <- function(model, fitfram, ci.lvl, linv, value_adjustment, terms, model_class, condition, interval, ...) {
 
   se <- (!is.null(ci.lvl) && !is.na(ci.lvl))
 
@@ -8,12 +8,15 @@ get_predictions_mixor <- function(model, fitfram, ci.lvl, linv, value_adjustment
   else
     ci <- 0.975
 
-  prdat <-
-    stats::predict(
-      model,
-      newdata = fitfram,
-      ...
-    )
+  # degrees of freedom
+  dof <- .get_df(model)
+  tcrit <- stats::qt(ci, df = dof)
+
+  prdat <- stats::predict(
+    model,
+    newdata = fitfram,
+    ...
+  )
 
   prdat <- as.data.frame(prdat$predicted)
 
@@ -26,23 +29,23 @@ get_predictions_mixor <- function(model, fitfram, ci.lvl, linv, value_adjustment
 
   fitfram <- .gather(fitfram, names_to = "response.level", values_to = "predicted", colnames(prdat))
 
-  se.pred <-
-    .standard_error_predictions(
-      model = model,
-      prediction_data = fitfram,
-      value_adjustment = value_adjustment,
-      terms = terms,
-      model_class = model_class,
-      condition = condition
-    )
+  se.pred <- .standard_error_predictions(
+    model = model,
+    prediction_data = fitfram,
+    value_adjustment = value_adjustment,
+    terms = terms,
+    model_class = model_class,
+    condition = condition,
+    interval = interval
+  )
 
   if (.check_returned_se(se.pred) && isTRUE(se)) {
     se.fit <- se.pred$se.fit
     fitfram <- se.pred$prediction_data
 
     # CI
-    fitfram$conf.low <- linv(stats::qlogis(fitfram$predicted) - stats::qnorm(ci) * se.fit)
-    fitfram$conf.high <- linv(stats::qlogis(fitfram$predicted) + stats::qnorm(ci) * se.fit)
+    fitfram$conf.low <- linv(stats::qlogis(fitfram$predicted) - tcrit * se.fit)
+    fitfram$conf.high <- linv(stats::qlogis(fitfram$predicted) + tcrit * se.fit)
 
     # copy standard errors
     attr(fitfram, "std.error") <- se.fit
