@@ -2,14 +2,13 @@ get_predictions_svyglmnb <- function(model, fitfram, ci.lvl, linv, model_class,
   # does user want standard errors?
   se <- !is.null(ci.lvl) && !is.na(ci.lvl)
 
-  prdat <-
-    stats::predict(
-      model,
-      newdata = fitfram,
-      type = "link",
-      se.fit = se,
-      ...
-    )
+  prdat <- stats::predict(
+    model,
+    newdata = fitfram,
+    type = "link",
+    se.fit = se,
+    ...
+  )
 
   # copy predictions
   .generic_prediction_data(model, fitfram, linv, prdat, se, ci.lvl, model_class, value_adjustment, terms, vcov.fun, vcov.type, vcov.args, condition, interval)
