@@ -64,7 +64,8 @@ ggemmeans <- function(model,
   model_info <- .get_model_info(model)
 
   # get model frame
-  original_model_frame <- model_frame <- insight::get_data(model, source = "frame")
+  model_frame <- .get_model_data(model)
+  original_model_frame <- model_frame
 
   # check terms argument
   terms <- .check_vars(terms, model)
