@@ -1,14 +1,12 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("lme4") &&
-  require("sjlabelled")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("lme4") &&
+  requiet("sjlabelled")
 )) {
-  context("ggeffects, lmer-contrasts")
+  data(efc, package = "ggeffects")
 
-  data(efc)
-
-  efc$e15relat <- as_label(efc$e15relat)
+  efc$e15relat <- sjlabelled::as_label(efc$e15relat)
 
   m <- lmer(neg_c_7 ~ c160age + c12hour + (1 | e15relat), data = efc)
 
