@@ -6,7 +6,7 @@ if (suppressWarnings(
 )) {
   # lm, linear regression ----
 
-  data(efc)
+  data(efc, package = "ggeffects")
   efc$c172code <- to_label(efc$c172code)
   fit <- lm(barthtot ~ c12hour + neg_c_7 + c161sex + c172code, data = efc)
 
@@ -33,4 +33,35 @@ if (suppressWarnings(
     p <- suppressWarnings(plot(pr, colors = "gs"))
   })
 
+  test_that("plot, correct x-labels order for character vector", {
+    d_char <- data.frame(
+      x = c("low", "low", "high", "high"),
+      y = c(0, 1, 10, 12),
+      stringsAsFactors = FALSE
+    )
+    m_char <- lm(y ~ x, data = d_char)
+    preds <- ggpredict(m_char, terms = "x [all]")
+    expect_identical(
+      attributes(preds)$x.axis.labels,
+      c("high", "low")
+    )
+
+    preds <- ggpredict(m_char, terms = "x")
+    expect_identical(
+      attributes(preds)$x.axis.labels,
+      c("low", "high")
+    )
+
+    d_char <- data.frame(
+      x = factor(c("low", "low", "high", "high")),
+      y = c(0, 1, 10, 12),
+      stringsAsFactors = FALSE
+    )
+    m_char <- lm(y ~ x, data = d_char)
+    preds <- ggpredict(m_char, terms = "x [all]")
+    expect_identical(
+      attributes(preds)$x.axis.labels,
+      c("high", "low")
+    )
+  })
 }
