@@ -1,10 +1,9 @@
 if (suppressWarnings(
-  require("testthat") &&
-  require("ggeffects") &&
-  require("AER")
+  requiet("testthat") &&
+  requiet("ggeffects") &&
+  requiet("AER")
 )) {
   unloadNamespace("VGAM")
-  context("ggeffects, tobit")
 
   data("Affairs")
   m1 <- tobit(affairs ~ age + yearsmarried + religiousness + occupation + rating, data = Affairs)
